@@ -198,7 +198,7 @@ def fracfact(gen):
 
     """
     # Recognize letters and combinations
-    A = [item for item in re.split('\-?\s?\+?', gen) if item]  # remove empty strings
+    A = [item for item in re.split('\-|\s|\+', gen) if item]  # remove empty strings
     C = [len(item) for item in A]
 
     # Indices of single letters (main factors)
